.. histmp documentation master file, created by
   sphinx-quickstart on Thu Jan 16 10:06:06 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

******
histmp
******

When you want to calculate histograms with blazing speed.



.. toctree::
   :caption: Documentation
   :maxdepth: 2

   quickstart
   api


.. Indices and tables
.. ==================

.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`
